# -*- coding: utf-8 -*-

"""Console script for biocode_fims."""

import click


@click.command()
def main(args=None):
    """Console script for biocode_fims."""
    click.echo("Replace this message by putting your code into "
               "biocode_fims.cli.main")

if __name__ == "__main__":
    main()
